@@ -1,6 +1,10 @@
 from pythonbrew.basecommand import Command
 from pythonbrew.log import logger
-from pythonbrew.installer import PythonInstaller
+from pythonbrew.installer.pythoninstaller import PythonInstaller,\
+    PythonInstallerMacOSX
+from pythonbrew.util import is_macosx_snowleopard
+from pythonbrew.exceptions import UnknownVersionException,\
+    AlreadyInstalledException, NotSupportedVersionException
 
 class InstallCommand(Command):
     name = "install"
@@ -36,11 +40,30 @@ class InstallCommand(Command):
             default=None,
             help="Install a python under an alias."
         )
+        self.parser.add_option(
+            '-j', "--jobs",
+            dest="jobs",
+            type='int',
+            default=0,
+            help="Enable parallel make."
+        )
     
     def run_command(self, options, args):
         if args:
-            # Install Python
-            PythonInstaller(args[0], options).install()
+            # Install pythons
+            for arg in args:
+                try:
+                    if is_macosx_snowleopard():
+                        p = PythonInstallerMacOSX(arg, options)
+                    else:
+                        p = PythonInstaller(arg, options)
+                    p.install()
+                except UnknownVersionException:
+                    continue
+                except AlreadyInstalledException:
+                    continue
+                except NotSupportedVersionException:
+                    continue
         else:
             logger.info("Unknown python version.")
     
