@@ -28,25 +28,31 @@ class PyCommand(Command):
             default=False,
             help="Show the running python version."
         )
+        self.parser.disable_interspersed_args()
     
     def run_command(self, options, args):
         if not args:
             logger.info("Unrecognized command line argument: argument not found.")
             sys.exit(1)
-        python_file = args[0]
-        
         pythons = self._get_pythons(options.pythons)
         for d in pythons:
-            path = os.path.join(PATH_PYTHONS, d, 'bin', 'python')
+            if options.verbose:
+                logger.info('*** %s ***' % d)
+            path = os.path.join(PATH_PYTHONS, d, 'bin', args[0])
             if os.path.isfile(path) and os.access(path, os.X_OK):
-                if options.verbose:
-                    logger.info('*** %s ***' % d)
-                p = Popen("%s %s" % (path, python_file), shell=True)
+                p = Popen("%s %s" % (path, ' '.join(args[1:])), shell=True)
                 p.wait()
+            else:
+                path = os.path.join(PATH_PYTHONS, d, 'bin', 'python')
+                if os.path.isfile(path) and os.access(path, os.X_OK):
+                    p = Popen("%s %s" % (path, ' '.join(args)), shell=True)
+                    p.wait()
+                else:
+                    logger.info('%s: No such file or directory.' % path)
     
     def _get_pythons(self, _pythons):
         pythons = [Package(p).name for p in _pythons]
-        return [d for d in sorted(os.listdir(PATH_PYTHONS)) 
+        return [d for d in sorted(os.listdir(PATH_PYTHONS))
                 if not pythons or d in pythons]
 
 PyCommand()
